from setuptools import setup, find_packages
setup(
    name='Unstop',
    version='1.0',
    license='MIT',
    author="Paras Gupta",
    author_email='paras@unstop.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='',
    keywords='Unstop',
)